==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SAMLHookResponseCommandsInnerValueInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SAMLHookResponseCommandsInnerValueInnerValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLHookResponseCommandsInnerValueInner
 */
@JsonPropertyOrder({ SAMLHookResponseCommandsInnerValueInner.JSON_PROPERTY_OP,
        SAMLHookResponseCommandsInnerValueInner.JSON_PROPERTY_PATH,
        SAMLHookResponseCommandsInnerValueInner.JSON_PROPERTY_VALUE })
@JsonTypeName("SAMLHookResponse_commands_inner_value_inner")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SAMLHookResponseCommandsInnerValueInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_OP = "op";
    private String op;

    public static final String JSON_PROPERTY_PATH = "path";
    private String path;

    public static final String JSON_PROPERTY_VALUE = "value";
    private SAMLHookResponseCommandsInnerValueInnerValue value;

    public SAMLHookResponseCommandsInnerValueInner() {
    }

    public SAMLHookResponseCommandsInnerValueInner op(String op) {

        this.op = op;
        return this;
    }

    /**
     * The name of one of the supported ops: &#x60;add&#x60;: Add a new claim to the assertion &#x60;replace&#x60;:
     * Modify any element of the assertion &gt; **Note:** If a response to the SAML assertion inline hook request
     * isn&#39;t received from your external service within three seconds, a timeout occurs. In this scenario, the Okta
     * process flow continues with the original SAML assertion returned.
     *
     * @return op
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The name of one of the supported ops: `add`:  Add a new claim to the assertion `replace`: Modify any element of the assertion  > **Note:** If a response to the SAML assertion inline hook request isn't received from your external service within three seconds, a timeout occurs. In this scenario, the Okta process flow continues with the original SAML assertion returned.")
    @JsonProperty(JSON_PROPERTY_OP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getOp() {
        return op;
    }

    @JsonProperty(JSON_PROPERTY_OP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOp(String op) {
        this.op = op;
    }

    public SAMLHookResponseCommandsInnerValueInner path(String path) {

        this.path = path;
        return this;
    }

    /**
     * Location, within the assertion, to apply the operation
     *
     * @return path
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Location, within the assertion, to apply the operation")
    @JsonProperty(JSON_PROPERTY_PATH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPath() {
        return path;
    }

    @JsonProperty(JSON_PROPERTY_PATH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPath(String path) {
        this.path = path;
    }

    public SAMLHookResponseCommandsInnerValueInner value(SAMLHookResponseCommandsInnerValueInnerValue value) {

        this.value = value;
        return this;
    }

    /**
     * Get value
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public SAMLHookResponseCommandsInnerValueInnerValue getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(SAMLHookResponseCommandsInnerValueInnerValue value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLHookResponseCommandsInnerValueInner saMLHookResponseCommandsInnerValueInner = (SAMLHookResponseCommandsInnerValueInner) o;
        return Objects.equals(this.op, saMLHookResponseCommandsInnerValueInner.op)
                && Objects.equals(this.path, saMLHookResponseCommandsInnerValueInner.path)
                && Objects.equals(this.value, saMLHookResponseCommandsInnerValueInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(op, path, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLHookResponseCommandsInnerValueInner {\n");
        sb.append("    op: ").append(toIndentedString(op)).append("\n");
        sb.append("    path: ").append(toIndentedString(path)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SAMLHookResponseCommandsInnerValueInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SAMLHookResponseCommandsInnerValueInnerValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLHookResponseCommandsInnerValueInner
 */
@JsonPropertyOrder({ SAMLHookResponseCommandsInnerValueInner.JSON_PROPERTY_OP,
        SAMLHookResponseCommandsInnerValueInner.JSON_PROPERTY_PATH,
        SAMLHookResponseCommandsInnerValueInner.JSON_PROPERTY_VALUE })
@JsonTypeName("SAMLHookResponse_commands_inner_value_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class SAMLHookResponseCommandsInnerValueInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_OP = "op";
    private String op;

    public static final String JSON_PROPERTY_PATH = "path";
    private String path;

    public static final String JSON_PROPERTY_VALUE = "value";
    private SAMLHookResponseCommandsInnerValueInnerValue value;

    public SAMLHookResponseCommandsInnerValueInner() {
    }

    public SAMLHookResponseCommandsInnerValueInner op(String op) {

        this.op = op;
        return this;
    }

    /**
     * The name of one of the supported ops: &#x60;add&#x60;: Add a new claim to the assertion &#x60;replace&#x60;:
     * Modify any element of the assertion &gt; **Note:** If a response to the SAML assertion inline hook request
     * isn&#39;t received from your external service within three seconds, a timeout occurs. In this scenario, the Okta
     * process flow continues with the original SAML assertion returned.
     *
     * @return op
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The name of one of the supported ops: `add`:  Add a new claim to the assertion `replace`: Modify any element of the assertion  > **Note:** If a response to the SAML assertion inline hook request isn't received from your external service within three seconds, a timeout occurs. In this scenario, the Okta process flow continues with the original SAML assertion returned.")
    @JsonProperty(JSON_PROPERTY_OP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getOp() {
        return op;
    }

    @JsonProperty(JSON_PROPERTY_OP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOp(String op) {
        this.op = op;
    }

    public SAMLHookResponseCommandsInnerValueInner path(String path) {

        this.path = path;
        return this;
    }

    /**
     * Location, within the assertion, to apply the operation
     *
     * @return path
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Location, within the assertion, to apply the operation")
    @JsonProperty(JSON_PROPERTY_PATH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPath() {
        return path;
    }

    @JsonProperty(JSON_PROPERTY_PATH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPath(String path) {
        this.path = path;
    }

    public SAMLHookResponseCommandsInnerValueInner value(SAMLHookResponseCommandsInnerValueInnerValue value) {

        this.value = value;
        return this;
    }

    /**
     * Get value
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public SAMLHookResponseCommandsInnerValueInnerValue getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(SAMLHookResponseCommandsInnerValueInnerValue value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLHookResponseCommandsInnerValueInner saMLHookResponseCommandsInnerValueInner = (SAMLHookResponseCommandsInnerValueInner) o;
        return Objects.equals(this.op, saMLHookResponseCommandsInnerValueInner.op)
                && Objects.equals(this.path, saMLHookResponseCommandsInnerValueInner.path)
                && Objects.equals(this.value, saMLHookResponseCommandsInnerValueInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(op, path, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLHookResponseCommandsInnerValueInner {\n");
        sb.append("    op: ").append(toIndentedString(op)).append("\n");
        sb.append("    path: ").append(toIndentedString(path)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
